@@ -31,6 +31,15 @@ class TestDBAdaptor:
             os.remove(expect_cache_file_path)
         return db
 
+    def test_delete_by_id_range(self, db: DBAdaptor):
+        # Insert two records to fund
+        entity_list = list()
+        for i in range(5):
+            fund = Fund()
+            fund.ticker = "40000" + str(i)
+            entity_list.append(fund)
+        db.save_all(entity_list)
+
     def test_cache_file_name(self, db):
         cache1 = db.get_hash_filename("select * from pyb.fund")
         assert 5 == len(cache1)
@@ -97,3 +106,11 @@ class TestDBAdaptor:
         assert ss is not None
         assert ss.table_name == "equity"
         assert ss.rc
+
+    def test_execute_any_sql(self, db: DBAdaptor):
+        db.execute_any_sql(
+            "update pyb.sync_status set comment='update by test_execute_any_sql' where id =1 "
+        )
+        syncstatus = db.get_any_by_id(SyncStatus, 1)
+
+        assert "update by test_execute_any_sql" == syncstatus.comment
